
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 36
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 121
#define YY_END_OF_BUFFER 122
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[711] =
    {   0,
      122,  120,  121,    3,  120,  121,    1,  121,   36,  120,
      121,  120,  121,   11,  120,  121,   31,  120,  121,   33,
      120,  121,  120,  121,   20,  120,  121,   21,  120,  121,
       29,  120,  121,   27,  120,  121,   60,  120,  121,   28,
      120,  121,   26,  120,  121,   30,  120,  121,  113,  120,
      121,  113,  120,  121,   23,  120,  121,   22,  120,  121,
       38,  120,  121,   37,  120,  121,   39,  120,  121,   25,
      120,  121,   74,  110,  120,  121,   74,  110,  120,  121,
       16,  120,  121,  120,  121,   18,  120,  121,   32,  120,
      121,   74,  110,  120,  121,   74,  110,  120,  121,   74,

      110,  120,  121,   74,  110,  120,  121,   74,  110,  120,
      121,   74,  110,  120,  121,   74,  110,  120,  121,   74,
      110,  120,  121,   74,  110,  120,  121,   74,  110,  120,
      121,   74,  110,  120,  121,   74,  110,  120,  121,   74,
      110,  120,  121,   74,  110,  120,  121,   74,  110,  120,
      121,   74,  110,  120,  121,   12,  120,  121,   34,  120,
      121,   14,  120,  121,   35,  120,  121,    3,    1,   53,
      118,   44,   15,   56,   46,  116,   42,   58,   40,   59,
       41,   61,  114,    4,    6,   43,  114,  112,  113,  113,
      113,  113,   19,   13,   17,   48,   54,   52,   55,   49,

       74,  110,    2,   45,   74,  110,   74,  110,   74,  110,
       74,  110,   74,  110,   74,  110,   74,  110,   74,  110,
       74,  110,   74,   83,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,   91,  110,
       74,  110,   74,  110,   74,  110,   74,  110,   74,  110,
       74,  110,   74,  110,   74,  110,   74,  110,   74,  110,
       74,  110,   47,   57,   24,  114,    6,  112,  113,  112,
      113,  115,  113,  113,  113,  111,   50,   51,  119,  117,
       74,  110,   74,  110,   74,  110,   74,  110,   74,  110,
       74,  110,   74,  110,   74,  110,   74,  110,   74,   75,

      110,   74,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,   89,  110,   74,  110,   74,  110,
       74,   93,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,  114,  112,  113,  112,  113,
      112,  113,  115,  113,  111,  111,   74,  110,   74,  110,
       74,  110,   74,  110,   74,  110,   74,  110,   74,  110,
       74,  110,   74,  110,   74,  110,   74,   76,  110,   74,

      110,   74,   78,  110,   74,   79,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,   85,  110,   74,   86,
      110,   74,  110,   74,  110,   74,   90,  110,   74,  110,
       74,   94,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,  107,  110,
       74,  110,   74,  110,   10,  112,  113,  111,  111,  111,
       73,   74,  110,   62,   74,  110,   74,  110,   74,  110,
       74,  110,   74,  110,   74,  110,   74,  110,   74,  110,
       74,  110,   74,   77,  110,   74,   80,  110,   74,  110,

       74,  110,   74,  110,   74,  110,   74,   88,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,   98,  110,
       74,  110,   74,  110,   74,  110,   74,  110,   74,  110,
       74,  110,   74,  105,  110,   74,  110,   74,  110,   74,
      109,  110,  111,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,   84,  110,   74,   87,
      110,   74,   92,  110,   74,  110,   74,  110,   74,   97,
      110,   74,   99,  110,   74,  100,  110,   74,  101,  110,
       74,  102,  110,   74,  103,  110,   74,  110,   74,  110,

       74,  110,    5,   63,   74,  110,   74,  110,   66,   74,
      110,   74,  110,   74,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   74,  110,   74,   82,  110,   74,  110,
       74,  110,   74,  104,  110,   74,  110,   74,  110,   74,
      110,   74,  110,   68,   74,  110,   74,  110,   74,  110,
       74,  110,   72,   74,  110,   74,   81,  110,   74,   95,
      110,   74,   96,  110,   74,  106,  110,   74,  108,  110,
        8,    9,   74,  110,   74,  110,   69,   74,  110,   74,
      110,   74,  110,    7,    8,   74,  110,   74,  110,   71,
       74,  110,   70,   74,  110,   65,   74,  110,   74,  110,

       74,  110,   74,  110,   64,   74,  110,   67,   74,  110
    } ;

static yyconst flex_int16_t yy_accept[377] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   84,   86,   89,   92,   96,  100,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  159,  162,  165,  168,  169,  170,  171,  171,  172,
      172,  172,  172,  172,  173,  174,  175,  176,  176,  177,
      177,  178,  179,  180,  181,  182,  183,  183,  184,  185,
      186,  187,  188,  190,  191,  191,  192,  193,  193,  194,
      195,  196,  197,  198,  199,  200,  201,  203,  203,  203,

      204,  205,  207,  209,  211,  213,  215,  217,  219,  221,
      223,  226,  228,  230,  232,  234,  236,  238,  241,  243,
      245,  247,  249,  251,  253,  255,  257,  259,  261,  263,
      264,  265,  265,  265,  265,  266,  266,  267,  267,  267,
      268,  270,  272,  272,  273,  274,  275,  276,  277,  278,
      279,  279,  280,  280,  280,  281,  281,  283,  285,  287,
      289,  291,  293,  295,  297,  299,  302,  304,  306,  308,
      310,  312,  314,  316,  318,  320,  322,  324,  327,  329,
      331,  334,  336,  338,  340,  342,  344,  346,  348,  350,
      352,  354,  356,  358,  360,  362,  364,  366,  366,  366,

      366,  366,  367,  367,  369,  371,  373,  374,  375,  376,
      377,  379,  381,  383,  385,  387,  389,  391,  393,  395,
      397,  400,  402,  405,  408,  410,  412,  414,  416,  419,
      422,  424,  426,  429,  431,  434,  436,  438,  440,  442,
      444,  446,  448,  450,  452,  454,  456,  458,  461,  463,
      465,  465,  466,  466,  466,  466,  468,  469,  470,  471,
      474,  477,  479,  481,  483,  485,  487,  489,  491,  493,
      496,  499,  501,  503,  505,  507,  510,  512,  514,  516,
      518,  521,  523,  525,  527,  529,  531,  533,  536,  538,
      540,  543,  543,  543,  543,  543,  544,  546,  548,  550,

      552,  554,  556,  558,  560,  562,  564,  566,  569,  572,
      575,  577,  579,  582,  585,  588,  591,  594,  597,  599,
      601,  603,  603,  603,  604,  607,  609,  612,  614,  616,
      618,  620,  622,  624,  626,  629,  631,  633,  636,  638,
      640,  640,  640,  642,  644,  647,  649,  651,  653,  656,
      659,  662,  665,  668,  671,  672,  672,  673,  675,  677,
      680,  682,  684,  685,  686,  688,  690,  693,  696,  699,
      701,  703,  705,  708,  711,  711
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   21,
       21,   21,   21,   21,   21,   22,   22,   23,   24,   25,
       26,   27,   28,    1,   29,   30,   29,   29,   31,   32,
       33,   33,   33,   33,   33,   34,   33,   33,   33,   33,
       33,   33,   33,   33,   35,   33,   33,   36,   33,   33,
       37,   38,   39,   40,   41,    1,   42,   43,   44,   45,

       46,   47,   48,   49,   50,   33,   51,   52,   53,   54,
       55,   56,   33,   57,   58,   59,   60,   61,   62,   63,
       64,   65,   66,   67,   68,   69,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[70] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    2,    1,    1,    1,    5,
        5,    5,    1,    1,    1,    2,    1,    1,    6,    6,
        6,    6,    7,    7,    7,    7,    1,    1,    1,    1,
        7,    6,    6,    6,    6,    6,    6,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[389] =
    {   0,
        0,    0,  571,  572,   68,    0,  544,   64,   69,   49,
       67,   67,  572,  572,  543,   64,  572,   65,   63,   75,
      108,   86,  541,  572,   86,  541,   60,  572,    0,   89,
      572,  563,  572,  539,   58,   55,  507,   61,   72,   70,
       79,  508,   93,  507,  515,   86,  496,  505,  503,  508,
      572,   97,  572,  572,  147,    0,  572,  112,  572,  553,
      135,  509,  497,  572,  572,  572,  572,  142,  572,  550,
      572,  572,  572,  572,  572,  572,  534,  141,  164,    0,
      572,  163,  182,  201,  209,  147,   46,    0,  572,  572,
      572,  525,  572,  572,  572,  524,    0,  152,  154,  572,

      572,  494,  206,  495,  488,  500,  487,  502,  489,  495,
      481,  482,  479,  479,  482,  479,  476,    0,  115,  480,
      153,  478,   93,  134,  482,  475,  120,  127,  480,  572,
      572,  246,  482,  486,  572,  223,  572,  502,    0,    0,
      220,  162,  237,  249,  173,  572,  239,  240,  572,  572,
      199,  572,  523,  187,  572,  522,  469,  218,  468,  459,
      467,  465,  473,  468,  453,    0,  461,  473,  468,  456,
      220,  470,  468,  464,  456,  462,  465,    0,  451,  455,
        0,  456,  453,  443,  441,  443,  445,  452,  438,  436,
      436,  448,  438,  442,  446,  448,  437,  485,  437,  438,

      264,  273,  458,  227,  572,  254,  572,  572,  263,  256,
      432,  430,  423,  427,  421,  427,  424,  419,  428,  419,
        0,  423,    0,    0,  414,  422,  411,  418,    0,    0,
      412,  409,    0,  413,    0,  408,  408,  407,  404,  416,
      406,  410,  415,  414,  412,  402,  407,    0,  395,  407,
      449,  572,  397,  397,  297,  572,  254,  572,  269,    0,
      408,  391,  389,  400,  395,  390,  384,  388,  395,    0,
        0,  386,  387,  392,  383,    0,  390,  376,  384,  379,
        0,  387,  384,  386,  370,  379,  381,    0,  372,  375,
        0,  378,  381,  408,  402,  572,  379,  369,  359,  363,

      362,  355,  357,  367,  357,  351,  351,    0,    0,    0,
      363,  364,    0,    0,    0,    0,    0,    0,  360,  360,
      353,  399,  398,  572,    0,  359,    0,  343,  354,  347,
      325,  329,  305,  282,    0,  267,  263,    0,  274,  272,
        0,  314,  256,  263,    0,  260,  266,  268,    0,    0,
        0,    0,    0,    0,  292,  279,  572,  190,  191,    0,
      182,  198,  572,  215,  174,  164,    0,    0,  164,  145,
       96,   56,    0,    0,  572,  325,  332,  339,  342,  349,
      352,  358,  365,  371,  378,  380,  387,  391
    } ;

static yyconst flex_int16_t yy_def[389] =
    {   0,
      375,    1,  375,  375,  375,  376,  375,  377,  375,  375,
      375,  378,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  379,  379,
      375,  375,  375,  375,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      375,  375,  375,  375,  375,  376,  375,  377,  375,  377,
      375,  375,  375,  375,  375,  375,  375,  378,  375,  378,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  380,
      375,  375,  375,  375,  375,  375,  375,  381,  375,  375,
      375,  375,  375,  375,  375,  375,  379,  382,  383,  375,

      375,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  384,  380,
      375,  375,  375,  375,  375,  375,  375,  381,  375,  375,
      382,  375,  382,  383,  375,  383,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  385,  375,  375,

      375,  375,  384,  375,  375,  375,  375,  375,  375,  375,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      385,  375,  375,  375,  375,  375,  375,  375,  375,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  375,  375,  375,  375,  375,  379,  379,  379,  379,

      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  375,  375,  375,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      386,  387,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,  388,  387,  375,  379,  379,  379,
      379,  379,  375,  388,  379,  379,  379,  379,  379,  379,
      379,  379,  379,  379,    0,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375
    } ;

static yyconst flex_int16_t yy_nxt[642] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   23,   24,   25,   26,   27,   28,   29,   29,
       29,   29,   29,   30,   29,   29,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   29,   43,
       29,   44,   29,   29,   29,   29,   45,   46,   47,   48,
       49,   50,   29,   29,   29,   51,   52,   53,   54,   55,
       59,   55,   55,   61,   64,   65,   66,   69,   72,  147,
       77,   74,   78,   78,   78,   95,   96,  102,   79,   73,
       75,   76,   67,   80,   90,   98,  374,  147,  103,   99,

       81,   60,  107,   82,   70,   84,   84,   84,   91,  108,
       92,   93,  104,   62,  105,  109,   85,  110,   59,   86,
       87,  112,  130,  113,   63,   82,  111,   83,   83,   84,
      115,   85,  114,  116,  122,  123,  373,   86,   85,  118,
      187,   86,   87,   88,  124,   87,  119,  125,   55,   60,
       55,   55,   69,   85,  132,  132,  132,  188,  152,   86,
       78,   78,   78,  131,  155,  138,  180,   87,  138,  193,
       88,  136,  137,  181,  137,  189,  195,  194,  196,   70,
      145,  146,   78,   78,   78,  372,  136,  137,  139,  153,
      190,  156,  137,  136,  137,  206,  137,  155,  145,   82,

      183,   83,   83,   84,  371,  152,  146,  146,  136,  137,
      184,  185,   85,  206,  137,  141,  142,  370,   82,  369,
       84,   84,   84,  143,  156,  143,  363,   85,  144,  144,
      144,   85,  146,  141,   86,   87,  153,  201,  368,  201,
      367,  142,  202,  202,  202,  366,   85,  158,  365,  159,
      198,  160,   86,  204,  205,  161,  144,  144,  144,  162,
       87,  205,  163,  164,  165,  132,  132,  132,  144,  144,
      144,  204,  208,  209,  210,  212,  213,  225,  226,  205,
      207,  357,  207,  202,  202,  202,  205,  256,  258,  259,
      208,  209,  202,  202,  202,  207,  257,  258,  294,  210,

      207,  294,  296,  363,  137,  256,  137,  259,  362,  361,
      295,  360,  359,  258,  257,  358,  357,  354,  353,  137,
      296,  352,  258,  351,  137,   56,   56,  350,   56,   56,
       56,   56,   58,   58,   58,   58,   58,   58,   58,   68,
       68,   68,   68,   68,   68,   68,   97,   97,   97,  140,
      140,  349,  140,  140,  140,  140,  148,  148,  151,  151,
      151,  151,  151,  151,  151,  154,  154,  154,  154,  154,
      154,  154,  203,  348,  347,  203,  203,  203,  251,  251,
      251,  251,  251,  251,  251,  355,  355,  356,  356,  356,
      356,  356,  356,  356,  364,  364,  364,  364,  346,  345,

      344,  343,  342,  341,  340,  339,  338,  337,  336,  335,
      334,  333,  332,  331,  330,  329,  328,  327,  326,  325,
      324,  295,  323,  322,  321,  320,  319,  318,  317,  316,
      315,  314,  313,  312,  311,  310,  309,  308,  307,  306,
      305,  304,  303,  302,  301,  300,  299,  298,  297,  293,
      292,  252,  291,  290,  289,  288,  287,  286,  285,  284,
      283,  282,  281,  280,  279,  278,  277,  276,  275,  274,
      273,  272,  271,  270,  269,  268,  267,  266,  265,  264,
      263,  262,  261,  260,  255,  254,  253,  252,  250,  249,
      248,  247,  246,  245,  244,  243,  242,  241,  240,  239,

      238,  237,  236,  235,  234,  233,  232,  231,  230,  229,
      228,  227,  224,  223,  222,  221,  220,  219,  218,  217,
      216,  215,  214,  211,  375,  375,  139,  200,  199,  197,
      192,  191,  186,  182,  179,  178,  177,  176,  175,  174,
      173,  172,  171,  170,  169,  168,  167,  166,  157,  150,
      149,  135,  375,  134,  133,  375,  129,  128,  127,  126,
      121,  120,  117,  106,  101,  100,   94,   89,   71,   57,
      375,    3,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,

      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375
    } ;

static yyconst flex_int16_t yy_chk[642] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    5,
        8,    5,    5,    9,   10,   10,   11,   12,   16,   87,
       19,   18,   19,   19,   19,   27,   27,   35,   20,   16,
       18,   18,   11,   20,   25,   30,  372,   87,   35,   30,

       20,    8,   38,   22,   12,   22,   22,   22,   25,   38,
       25,   25,   36,    9,   36,   38,   22,   39,   58,   22,
       22,   40,   52,   40,    9,   21,   39,   21,   21,   21,
       41,   22,   40,   41,   46,   46,  371,   22,   21,   43,
      123,   21,   21,   21,   46,   22,   43,   46,   55,   58,
       55,   55,   68,   21,   61,   61,   61,  123,   98,   21,
       78,   78,   78,   52,   99,   79,  119,   21,   79,  127,
       21,   78,   78,  119,   78,  124,  128,  127,  128,   68,
       86,   86,   82,   82,   82,  370,   78,   78,   79,   98,
      124,   99,   78,   82,   82,  142,   82,  154,   86,   83,

      121,   83,   83,   83,  369,  151,   86,  145,   82,   82,
      121,  121,   83,  142,   82,   83,   83,  366,   84,  365,
       84,   84,   84,   85,  154,   85,  364,   83,   85,   85,
       85,   84,  145,   83,   84,   84,  151,  136,  362,  136,
      361,   83,  136,  136,  136,  359,   84,  103,  358,  103,
      132,  103,   84,  141,  141,  103,  143,  143,  143,  103,
       84,  204,  103,  103,  103,  132,  132,  132,  144,  144,
      144,  141,  147,  148,  148,  158,  158,  171,  171,  141,
      144,  356,  144,  201,  201,  201,  204,  206,  257,  210,
      147,  148,  202,  202,  202,  144,  209,  209,  255,  148,

      144,  255,  259,  355,  202,  206,  202,  210,  348,  347,
      255,  346,  344,  257,  209,  343,  342,  340,  339,  202,
      259,  337,  209,  336,  202,  376,  376,  334,  376,  376,
      376,  376,  377,  377,  377,  377,  377,  377,  377,  378,
      378,  378,  378,  378,  378,  378,  379,  379,  379,  380,
      380,  333,  380,  380,  380,  380,  381,  381,  382,  382,
      382,  382,  382,  382,  382,  383,  383,  383,  383,  383,
      383,  383,  384,  332,  331,  384,  384,  384,  385,  385,
      385,  385,  385,  385,  385,  386,  386,  387,  387,  387,
      387,  387,  387,  387,  388,  388,  388,  388,  330,  329,

      328,  326,  323,  322,  321,  320,  319,  312,  311,  307,
      306,  305,  304,  303,  302,  301,  300,  299,  298,  297,
      295,  294,  293,  292,  290,  289,  287,  286,  285,  284,
      283,  282,  280,  279,  278,  277,  275,  274,  273,  272,
      269,  268,  267,  266,  265,  264,  263,  262,  261,  254,
      253,  251,  250,  249,  247,  246,  245,  244,  243,  242,
      241,  240,  239,  238,  237,  236,  234,  232,  231,  228,
      227,  226,  225,  222,  220,  219,  218,  217,  216,  215,
      214,  213,  212,  211,  203,  200,  199,  198,  197,  196,
      195,  194,  193,  192,  191,  190,  189,  188,  187,  186,

      185,  184,  183,  182,  180,  179,  177,  176,  175,  174,
      173,  172,  170,  169,  168,  167,  165,  164,  163,  162,
      161,  160,  159,  157,  156,  153,  138,  134,  133,  129,
      126,  125,  122,  120,  117,  116,  115,  114,  113,  112,
      111,  110,  109,  108,  107,  106,  105,  104,  102,   96,
       92,   77,   70,   63,   62,   60,   50,   49,   48,   47,
       45,   44,   42,   37,   34,   32,   26,   23,   15,    7,
        3,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,

      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  375,
      375
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "scannerlexer.l"
#include <ctype.h>
#include <stdio.h>

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"
#include "grealpath.h"

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
#line 856 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 65 "scannerlexer.l"


#line 1039 "scannerlexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 376 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 572 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 67 "scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 73 "scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 74 "scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 76 "scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 77 "scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 78 "scannerlexer.l"
{ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 80 "scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 81 "scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 82 "scannerlexer.l"
{ /* Ignore pragma. */ }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 84 "scannerlexer.l"
{ process_linemarks(scanner); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 85 "scannerlexer.l"
{ }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 86 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 87 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 88 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 89 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 90 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 91 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 92 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 93 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 94 "scannerlexer.l"
{ return '('; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 95 "scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 96 "scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 97 "scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 98 "scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 99 "scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 100 "scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 101 "scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 102 "scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 103 "scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 104 "scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 105 "scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 106 "scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 107 "scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 108 "scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 109 "scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 110 "scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 111 "scannerlexer.l"
{ return '='; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 112 "scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 113 "scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 114 "scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 115 "scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 116 "scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 117 "scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 118 "scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 119 "scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 120 "scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 121 "scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 122 "scannerlexer.l"
{ return SL; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 123 "scannerlexer.l"
{ return SR; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 124 "scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 125 "scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 126 "scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 127 "scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 128 "scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 129 "scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 130 "scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 131 "scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 132 "scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 133 "scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 134 "scannerlexer.l"
{ return ','; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 135 "scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 137 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 138 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 139 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 140 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 141 "scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 142 "scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 143 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 144 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 145 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 146 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 147 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 148 "scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 150 "scannerlexer.l"
{ if (scanner->macro_scan) return IDENTIFIER; else REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 152 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 153 "scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 154 "scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 155 "scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 156 "scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 157 "scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 158 "scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 159 "scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 160 "scannerlexer.l"
{ return DO; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 161 "scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 162 "scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 163 "scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 164 "scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 165 "scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 166 "scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 167 "scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 168 "scannerlexer.l"
{ return IF; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 169 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 170 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 171 "scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 172 "scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 173 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 174 "scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 175 "scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 176 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 177 "scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 178 "scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 179 "scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 180 "scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 181 "scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 182 "scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 183 "scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 184 "scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 185 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 186 "scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 188 "scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 190 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 191 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 192 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 194 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 195 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 116:
/* rule 116 can match eol */
YY_RULE_SETUP
#line 197 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 117:
/* rule 117 can match eol */
YY_RULE_SETUP
#line 198 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 118:
/* rule 118 can match eol */
YY_RULE_SETUP
#line 200 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 119:
/* rule 119 can match eol */
YY_RULE_SETUP
#line 201 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 203 "scannerlexer.l"
{ if (yytext[0]) fprintf(stderr, "%s:%d: unexpected character `%c'\n", scanner->current_filename, lineno, yytext[0]); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 205 "scannerlexer.l"
ECHO;
	YY_BREAK
#line 1749 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 376 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 376 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 375);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 205 "scannerlexer.l"



static int
yywrap (void)
{
  return 1;
}


static void
parse_comment (GISourceScanner *scanner)
{
  GString *string;
  int c1, c2;
  GISourceComment *comment;
  int comment_lineno;

  c1 = input();
  c2 = input();

  string = g_string_new ("");

  comment_lineno = lineno;

  while (c2 != EOF && !(c1 == '*' && c2 == '/'))
    {
      g_string_append_c (string, c1);

      if (c1 == '\n')
        lineno++;

      c1 = c2;
      c2 = input();

    }

  comment = g_slice_new (GISourceComment);
  comment->comment = g_string_free (string, FALSE);
  comment->line = comment_lineno;
  comment->filename = g_strdup(scanner->current_filename);

  scanner->comments = g_slist_prepend (scanner->comments,
                                       comment);
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner)
{
        char filename[1025];
        char *compress;
        char *real;

        sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, filename);

	compress = g_strcompress (filename);
        real = g_realpath (filename);
        if (real) {
                g_free (scanner->current_filename);
                scanner->current_filename = real;
        } else {
                g_free (real);
        }
        g_free (compress);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

